@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # vim: set fileencoding=utf-8:
 # @Author: Vayn a.k.a. VT <vayn@vayn.de>
 # @Name: config.py
@@ -21,3 +21,5 @@ DBURL = {'host': 'localhost',
          'port': 27017,
         }
 
+### Url length
+PAD = 3
